==> nextcloud-30.0.12.tar.bz2: nextcloud/apps/serverinfo/l10n/et_EE.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Protsessori info pole saadaval",
    "CPU Usage:" : "Protsessori koormus:",
    "Load average: {percentage} % ({load}) last minute" : "Keskmine koormus: {percentage} % ({load}) viimase minuti kestel",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) viimane minut\n{last5MinutesPercentage} % ({last5Minutes}) viimased 5 minutit\n{last15MinutesPercentage} % ({last15Minutes}) viimased 15 minutit",
    "RAM Usage:" : "Mälukasutus:",
    "SWAP Usage:" : "Saaleala kasutus:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "Mälu: Kokku: {memTotalBytes}/Kasutusel: {memUsageBytes}",
    "RAM info not available" : "Vahemälu info pole saadaval",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "Saaleala: Kokku: {swapTotalBytes}/Kasutusel: {swapUsageBytes}",
    "SWAP info not available" : "Saaleala info pole saadaval",
    "Copied!" : "Kopeeritud!",
    "Not supported!" : "Pole toetatud!",
    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘+C.",
    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl+C.",
    "System" : "Süsteem",
    "Monitoring" : "Monitooring",
    "Monitoring app with useful server information" : "Monitoorimisrakendus kasuliku infoga serveri kohta",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Näitab kasulikku infot serveri kohta, näiteks protsessori koormus, mälukasutus, kettaruum, kasutajate arv jne.",
    "Operating System:" : "Operatsioonisüsteem:",
    "CPU:" : "Protsessor:",
    "Unknown Processor" : "Tundmatu protsessor",
    "Memory:" : "Vahemälu:",
    "Server time:" : "Serveri aeg:",
    "Uptime:" : "Aktiivaeg:",
    "Temperature" : "Temperatuur",
    "Load" : "Koormus",
    "Memory" : "Vahemälu",
    "Disk" : "Ketas",
    "Mount:" : "Haakepunkt:",
    "Filesystem:" : "Failisüsteem:",
    "Size:" : "Suurus:",
    "Available:" : "Saadaval:",
    "Used:" : "Kasutusel:",
    "Files:" : "Faile:",
    "Storages:" : "Andmeruumid:",
    "Free Space:" : "Vaba ruum:",
    "Network" : "Võrk",
    "Hostname:" : "Hostinimi:",
    "Gateway:" : "Võrgulüüs:",
    "Status:" : "Seisund:",
    "Speed:" : "Kiirus:",
    "Duplex:" : "Dupleks:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktiivseid kasutajaid",
    "Last hour" : "Viimase tunni jooksul",
    "%s%% of all users" : "%s%% kõikidest kasutajatest",
    "Last 24 Hours" : "Viimase 24 tunni jooksul",
    "Last 7 Days" : "Viimase 7 päeva jooksul",
    "Last 30 Days" : "Viimase 30 päeva jooksul",
    "Shares" : "Jaoskaustad",
    "Users:" : "Kasutajaid:",
    "Groups:" : "Gruppe:",
    "Links:" : "Linke:",
    "Emails:" : "E-kirju:",
    "Federated sent:" : "Liitpilve saadetud:",
    "Federated received:" : "Liitpilvest vastu võetud:",
    "Talk conversations:" : "Vestlusi suhtlusrakenduses:",
    "PHP" : "PHP",
    "Version:" : "Versioon:",
    "Memory limit:" : "Mälukasutuse ülempiir:",
    "Max execution time:" : "Maksimaalne täitmisaeg:",
    "Upload max size:" : "Maksimaalne üleslaadimissuurus:",
    "OPcache Revalidate Frequency:" : "OPcache'i kordusvalideerimise sagedus:",
    "Extensions:" : "Laiendused:",
    "Unable to list extensions" : "Laienduste loetlemine ebaõnnestus",
    "Show phpinfo" : "Näita phpinfo väljundit",
    "FPM worker pool" : "FPM-i ühenduste fond",
    "Pool name:" : "Ühenduste fondi nimi:",
    "Pool type:" : "Ühenduste fondi tüüp:",
    "Start time:" : "Algusaeg:",
    "Accepted connections:" : "Vastuvõetud ühendusi:",
    "Total processes:" : "Protsesse kokku:",
    "Active processes:" : "Aktiivseid protsesse:",
    "Idle processes:" : "Jõude protsesse:",
    "Listen queue:" : "Kuulatavate päringute järjekord:",
    "Slow requests:" : "Aeglaseid päringuid:",
    "Max listen queue:" : "Maksimaalne kuulatavate päringute järjekord:",
    "Max active processes:" : "Suurim aktiivsete protsesside arv:",
    "Max children reached:" : "Maksimaalselt järglasprotsesse:",
    "Database" : "Andmebaas",
    "Type:" : "Tüüp:",
    "External monitoring tool" : "Väline monitoorimistarvik",
    "Use this end point to connect an external monitoring tool:" : "Kasuta seda otspunkti välise monitoorimistarviku ühenduse jaoks:",
    "Copy" : "Kopeeri",
    "Output in JSON" : "Väljund json-vormingus",
    "Skip apps section (including apps section will send an external request to the app store)" : "Jäta rakenduste valik vahele (sh sellega seotud päring rakendustepoodi)",
    "Skip server update" : "Jäta serveri uuendus vahele",
    "To use an access token, please generate one then set it using the following command:" : "Ligipääsutunnuse kasutamiseks genereeri see ja seadista alljärgneva käsu abil:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Seejärel saada tunnus ülaloleva URL-i pärimisel \"NC-Token\" päisega."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.16.tar.bz2: nextcloud/apps/serverinfo/l10n/et_EE.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Protsessori info pole saadaval",
    "CPU Usage:" : "Protsessori koormus:",
    "Load average: {percentage} % ({load}) last minute" : "Keskmine koormus: {percentage} % ({load}) viimase minuti kestel",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) viimane minut\n{last5MinutesPercentage} % ({last5Minutes}) viimased 5 minutit\n{last15MinutesPercentage} % ({last15Minutes}) viimased 15 minutit",
    "RAM Usage:" : "Mälukasutus:",
    "SWAP Usage:" : "Saaleala kasutus:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "Mälu: Kokku: {memTotalBytes}/Kasutusel: {memUsageBytes}",
    "RAM info not available" : "Vahemälu info pole saadaval",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "Saaleala: Kokku: {swapTotalBytes}/Kasutusel: {swapUsageBytes}",
    "SWAP info not available" : "Saaleala info pole saadaval",
    "Copied!" : "Kopeeritud!",
    "Not supported!" : "Pole toetatud!",
    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘+C.",
    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl+C.",
    "System" : "Süsteem",
    "Monitoring" : "Monitooring",
    "Monitoring app with useful server information" : "Monitoorimisrakendus kasuliku infoga serveri kohta",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Näitab kasulikku infot serveri kohta, näiteks protsessori koormus, mälukasutus, kettaruum, kasutajate arv jne.",
    "Operating System:" : "Operatsioonisüsteem:",
    "CPU:" : "Protsessor:",
    "threads" : "lõimesid",
    "Memory:" : "Vahemälu:",
    "Server time:" : "Serveri aeg:",
    "Uptime:" : "Aktiivaeg:",
    "Temperature" : "Temperatuur",
    "Load" : "Koormus",
    "Memory" : "Vahemälu",
    "Disk" : "Ketas",
    "Mount:" : "Haakepunkt:",
    "Filesystem:" : "Failisüsteem:",
    "Size:" : "Suurus:",
    "Available:" : "Saadaval:",
    "Used:" : "Kasutusel:",
    "Files:" : "Faile:",
    "Storages:" : "Andmeruumid:",
    "Free Space:" : "Vaba ruum:",
    "Network" : "Võrk",
    "Hostname:" : "Hostinimi:",
    "Gateway:" : "Võrgulüüs:",
    "Status:" : "Seisund:",
    "Speed:" : "Kiirus:",
    "Duplex:" : "Dupleks:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktiivseid kasutajaid",
    "Last hour" : "Viimase tunni jooksul",
    "%s%% of all users" : "%s%% kõikidest kasutajatest",
    "Last 24 Hours" : "Viimase 24 tunni jooksul",
    "Last 7 Days" : "Viimase 7 päeva jooksul",
    "Last 30 Days" : "Viimase 30 päeva jooksul",
    "Shares" : "Jaoskaustad",
    "Users:" : "Kasutajaid:",
    "Groups:" : "Gruppe:",
    "Links:" : "Linke:",
    "Emails:" : "E-kirju:",
    "Federated sent:" : "Liitpilve saadetud:",
    "Federated received:" : "Liitpilvest vastu võetud:",
    "Talk conversations:" : "Vestlusi suhtlusrakenduses:",
    "PHP" : "PHP",
    "Version:" : "Versioon:",
    "Memory limit:" : "Mälukasutuse ülempiir:",
    "Max execution time:" : "Maksimaalne täitmisaeg:",
    "Upload max size:" : "Maksimaalne üleslaadimissuurus:",
    "OPcache Revalidate Frequency:" : "OPcache'i kordusvalideerimise sagedus:",
    "Extensions:" : "Laiendused:",
    "Unable to list extensions" : "Laienduste loetlemine ebaõnnestus",
    "Show phpinfo" : "Näita phpinfo väljundit",
    "FPM worker pool" : "FPM-i ühenduste fond",
    "Pool name:" : "Ühenduste fondi nimi:",
    "Pool type:" : "Ühenduste fondi tüüp:",
    "Start time:" : "Algusaeg:",
    "Accepted connections:" : "Vastuvõetud ühendusi:",
    "Total processes:" : "Protsesse kokku:",
    "Active processes:" : "Aktiivseid protsesse:",
    "Idle processes:" : "Jõude protsesse:",
    "Listen queue:" : "Kuulatavate päringute järjekord:",
    "Slow requests:" : "Aeglaseid päringuid:",
    "Max listen queue:" : "Maksimaalne kuulatavate päringute järjekord:",
    "Max active processes:" : "Suurim aktiivsete protsesside arv:",
    "Max children reached:" : "Maksimaalselt järglasprotsesse:",
    "Database" : "Andmebaas",
    "Type:" : "Tüüp:",
    "External monitoring tool" : "Väline monitoorimistarvik",
    "Use this end point to connect an external monitoring tool:" : "Kasuta seda otspunkti välise monitoorimistarviku ühenduse jaoks:",
    "Copy" : "Kopeeri",
    "Output in JSON" : "Väljund json-vormingus",
    "Skip apps section (including apps section will send an external request to the app store)" : "Jäta rakenduste valik vahele (sh sellega seotud päring rakendustepoodi)",
    "Skip server update" : "Jäta serveri uuendus vahele",
    "To use an access token, please generate one then set it using the following command:" : "Ligipääsutunnuse kasutamiseks genereeri see ja seadista alljärgneva käsu abil:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Seejärel saada tunnus ülaloleva URL-i pärimisel \"NC-Token\" päisega.",
    "Unknown Processor" : "Tundmatu protsessor"
},
"nplurals=2; plural=(n != 1);");
